import OCP.CDF
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.PCDM
import OCP.Resource
import OCP.CDM
import OCP.Message
import OCP.Standard
__all__  = [
"CDF_Application",
"CDF_Directory",
"CDF_DirectoryIterator",
"CDF_MetaDataDriver",
"CDF_FWOSDriver",
"CDF_MetaDataDriverFactory",
"CDF_Store",
"CDF_StoreList",
"CDF_StoreSetNameStatus",
"CDF_SubComponentStatus",
"CDF_TryStoreStatus",
"CDF_TypeOfActivation",
"CDF_SCS_Consistent",
"CDF_SCS_Modified",
"CDF_SCS_Stored",
"CDF_SCS_Unconsistent",
"CDF_SSNS_OK",
"CDF_SSNS_OpenDocument",
"CDF_SSNS_ReplacingAnExistentDocument",
"CDF_TOA_Modified",
"CDF_TOA_New",
"CDF_TOA_Unchanged",
"CDF_TS_NoCurrentDocument",
"CDF_TS_NoDriver",
"CDF_TS_NoSubComponentDriver",
"CDF_TS_OK"
]
class CDF_Application(OCP.CDM.CDM_Application, OCP.Standard.Standard_Transient):
    def BeginOfUpdate(self,aDocument : OCP.CDM.CDM_Document) -> None: 
        """
        this method is called before the update of a document. By default, writes in MessageDriver().
        """
    def CanClose(self,aDocument : OCP.CDM.CDM_Document) -> OCP.CDM.CDM_CanCloseStatus: ...
    @overload
    def CanRetrieve(self,theFolder : OCP.TCollection.TCollection_ExtendedString,theName : OCP.TCollection.TCollection_ExtendedString,theAppendMode : bool) -> OCP.PCDM.PCDM_ReaderStatus: ...
    @overload
    def CanRetrieve(self,theFolder : OCP.TCollection.TCollection_ExtendedString,theName : OCP.TCollection.TCollection_ExtendedString,theVersion : OCP.TCollection.TCollection_ExtendedString,theAppendMode : bool) -> OCP.PCDM.PCDM_ReaderStatus: ...
    def Close(self,aDocument : OCP.CDM.CDM_Document) -> None: 
        """
        removes the document of the current session directory and closes the document;
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def DefaultFolder(self) -> str: ...
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def EndOfUpdate(self,aDocument : OCP.CDM.CDM_Document,theStatus : bool,ErrorString : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        this method is called after the update of a document. By default, writes in MessageDriver().
        """
    def Format(self,aFileName : OCP.TCollection.TCollection_ExtendedString,theFormat : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        try to retrieve a Format directly in the file or in application resource by using extension. returns True if found;
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetRetrieveStatus(self) -> OCP.PCDM.PCDM_ReaderStatus: 
        """
        Checks status after Retrieve
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def InitDocument(self,theDoc : OCP.CDM.CDM_Document) -> None: 
        """
        Initialize a document for the applicative session. This virtual function is called by NewDocument and should be redefined for each specific application.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @staticmethod
    def Load_s(aGUID : OCP.Standard.Standard_GUID) -> CDF_Application: 
        """
        plugs an application.
        """
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns default messenger;
        """
    def MetaDataDriver(self) -> CDF_MetaDataDriver: 
        """
        returns MetaDatdDriver of this application
        """
    def MetaDataLookUpTable(self) -> Any: 
        """
        Returns MetaData LookUpTable
        """
    def Name(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Returns the application name.
        """
    def NewDocument(self,theFormat : OCP.TCollection.TCollection_ExtendedString,theDoc : OCP.CDM.CDM_Document) -> Any: 
        """
        Constructs an new empty document. This document will have the specified format. If InitDocument() is redefined for a specific application, the new document is handled by the applicative session.
        """
    def Open(self,aDocument : OCP.CDM.CDM_Document) -> None: 
        """
        puts the document in the current session directory and calls the virtual method Activate on it.
        """
    def Read(self,theIStream : io.BytesIO,theDocument : OCP.CDM.CDM_Document,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> Any: 
        """
        Reads theDocument from standard SEEKABLE stream theIStream, the stream should support SEEK functionality
        """
    def ReaderFromFormat(self,aFormat : OCP.TCollection.TCollection_ExtendedString) -> OCP.PCDM.PCDM_Reader: 
        """
        Returns instance of read driver for specified format.
        """
    def Resources(self) -> OCP.Resource.Resource_Manager: 
        """
        The manager returned by this virtual method will be used to search for Format.Retrieval resource items.
        """
    @overload
    def Retrieve(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,UseStorageConfiguration : bool=True,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.CDM.CDM_Document: 
        """
        This method retrieves a document from the database. If the Document references other documents which have been updated, the latest version of these documents will be used if {UseStorageConfiguration} is Standard_True. The content of {aFolder}, {aName} and {aVersion} depends on the Database Manager system. If the DBMS is only based on the OS, {aFolder} is a directory and {aName} is the name of a file. In this case the use of the syntax with {aVersion} has no sense. For example:

        This method retrieves a document from the database. If the Document references other documents which have been updated, the latest version of these documents will be used if {UseStorageConfiguration} is Standard_True. -- If the DBMS is only based on the OS, this syntax should not be used.
        """
    @overload
    def Retrieve(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString,UseStorageConfiguration : bool=True,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.CDM.CDM_Document: ...
    def SetDefaultFolder(self,aFolder : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Version(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the application version.
        """
    def Write(self,aString : str) -> None: 
        """
        writes the string in the application MessagerDriver.
        """
    def WriterFromFormat(self,aFormat : OCP.TCollection.TCollection_ExtendedString) -> OCP.PCDM.PCDM_StorageDriver: 
        """
        Returns instance of storage driver for specified format.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDF_Directory(OCP.Standard.Standard_Transient):
    """
    A directory is a collection of documents. There is only one instance of a given document in a directory. put.A directory is a collection of documents. There is only one instance of a given document in a directory. put.A directory is a collection of documents. There is only one instance of a given document in a directory. put.
    """
    def Add(self,aDocument : OCP.CDM.CDM_Document) -> None: 
        """
        adds a document into the directory.
        """
    def Contains(self,aDocument : OCP.CDM.CDM_Document) -> bool: 
        """
        Returns true if the document aDocument is in the directory
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsEmpty(self) -> bool: 
        """
        returns true if the directory is empty.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> OCP.CDM.CDM_Document: 
        """
        returns the last document (if any) which has been added in the directory.
        """
    def Length(self) -> int: 
        """
        returns the number of documents of the directory.
        """
    def Remove(self,aDocument : OCP.CDM.CDM_Document) -> None: 
        """
        removes the document.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDF_DirectoryIterator():
    def Document(self) -> OCP.CDM.CDM_Document: 
        """
        Returns item value of current entry
        """
    def MoreDocument(self) -> bool: 
        """
        Returns True if there are more entries to return
        """
    def NextDocument(self) -> None: 
        """
        Go to the next entry (if there is not, Value will raise an exception)
        """
    def __init__(self,aDirectory : CDF_Directory) -> None: ...
    pass
class CDF_MetaDataDriver(OCP.Standard.Standard_Transient):
    """
    this class list the method that must be available for a specific DBMSthis class list the method that must be available for a specific DBMSthis class list the method that must be available for a specific DBMS
    """
    def BuildFileName(self,aDocument : OCP.CDM.CDM_Document) -> OCP.TCollection.TCollection_ExtendedString: ...
    def CreateDependsOn(self,aFirstData : OCP.CDM.CDM_MetaData,aSecondData : OCP.CDM.CDM_MetaData) -> None: 
        """
        Creates a "Depends On" relation between two Datas. By default does nothing
        """
    def CreateMetaData(self,aDocument : OCP.CDM.CDM_Document,aFileName : OCP.TCollection.TCollection_ExtendedString) -> OCP.CDM.CDM_MetaData: 
        """
        should create meta-data corresponding to aData and maintaining a meta-link between these meta-data and aFileName CreateMetaData is called by CreateData If the metadata-driver has version capabilities, version must be set in the returned Data.
        """
    def CreateReference(self,aFrom : OCP.CDM.CDM_MetaData,aTo : OCP.CDM.CDM_MetaData,aReferenceIdentifier : int,aToDocumentVersion : int) -> None: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def DefaultFolder(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    @overload
    def Find(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        should indicate whether meta-data exist in the DBMS corresponding to the Data. aVersion may be NULL;

        calls Find with an empty version
        """
    @overload
    def Find(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    def FindFolder(self,aFolder : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasReadPermission(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    def HasVersion(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        by default return Standard_True.
        """
    def HasVersionCapability(self) -> bool: 
        """
        returns true if the MetaDataDriver can manage different versions of a Data. By default, returns Standard_False.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def LastVersion(self,aMetaData : OCP.CDM.CDM_MetaData) -> OCP.CDM.CDM_MetaData: 
        """
        by default returns aMetaDATA should return the MetaData stored in the DBMS with the meta-data corresponding to the path. If the MetaDataDriver has version management capabilities the version has to be set in the returned MetaData. MetaData is called by GetMetaData If the version is not included in the path , MetaData should return the last version of the metadata is deferred;
        """
    @overload
    def MetaData(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString) -> OCP.CDM.CDM_MetaData: 
        """
        should return the MetaData stored in the DBMS with the meta-data corresponding to the Data. If the MetaDataDriver has version management capabilities the version has to be set in the returned MetaData. aVersion may be NULL MetaData is called by GetMetaData If the version is set to NULL, MetaData should return the last version of the metadata

        calls MetaData with an empty version
        """
    @overload
    def MetaData(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString) -> OCP.CDM.CDM_MetaData: ...
    def ReferenceIterator(self,theMessageDriver : OCP.Message.Message_Messenger) -> OCP.PCDM.PCDM_ReferenceIterator: ...
    def SetName(self,aDocument : OCP.CDM.CDM_Document,aName : OCP.TCollection.TCollection_ExtendedString) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        this method is useful if the name of an object -- depends on the metadatadriver. For example a Driver -- based on the operating system can choose to add the extension of file to create to the object.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDF_FWOSDriver(CDF_MetaDataDriver, OCP.Standard.Standard_Transient):
    def BuildFileName(self,aDocument : OCP.CDM.CDM_Document) -> OCP.TCollection.TCollection_ExtendedString: ...
    def CreateDependsOn(self,aFirstData : OCP.CDM.CDM_MetaData,aSecondData : OCP.CDM.CDM_MetaData) -> None: 
        """
        Creates a "Depends On" relation between two Datas. By default does nothing
        """
    def CreateMetaData(self,aDocument : OCP.CDM.CDM_Document,aFileName : OCP.TCollection.TCollection_ExtendedString) -> OCP.CDM.CDM_MetaData: 
        """
        should create meta-data corresponding to aData and maintaining a meta-link between these meta-data and aFileName CreateMetaData is called by CreateData If the metadata-driver has version capabilities, version must be set in the returned Data.
        """
    def CreateReference(self,aFrom : OCP.CDM.CDM_MetaData,aTo : OCP.CDM.CDM_MetaData,aReferenceIdentifier : int,aToDocumentVersion : int) -> None: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def DefaultFolder(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Find(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        indicate whether a file exists corresponding to the folder and the name
        """
    def FindFolder(self,aFolder : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasReadPermission(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    def HasVersion(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        by default return Standard_True.
        """
    def HasVersionCapability(self) -> bool: 
        """
        returns true if the MetaDataDriver can manage different versions of a Data. By default, returns Standard_False.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def LastVersion(self,aMetaData : OCP.CDM.CDM_MetaData) -> OCP.CDM.CDM_MetaData: 
        """
        by default returns aMetaDATA should return the MetaData stored in the DBMS with the meta-data corresponding to the path. If the MetaDataDriver has version management capabilities the version has to be set in the returned MetaData. MetaData is called by GetMetaData If the version is not included in the path , MetaData should return the last version of the metadata is deferred;
        """
    @overload
    def MetaData(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString) -> OCP.CDM.CDM_MetaData: 
        """
        should return the MetaData stored in the DBMS with the meta-data corresponding to the Data. If the MetaDataDriver has version management capabilities the version has to be set in the returned MetaData. aVersion may be NULL MetaData is called by GetMetaData If the version is set to NULL, MetaData should return the last version of the metadata

        calls MetaData with an empty version
        """
    @overload
    def MetaData(self,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString) -> OCP.CDM.CDM_MetaData: ...
    def ReferenceIterator(self,theMessageDriver : OCP.Message.Message_Messenger) -> OCP.PCDM.PCDM_ReferenceIterator: ...
    def SetName(self,aDocument : OCP.CDM.CDM_Document,aName : OCP.TCollection.TCollection_ExtendedString) -> OCP.TCollection.TCollection_ExtendedString: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self,theLookUpTable : Any) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDF_MetaDataDriverFactory(OCP.Standard.Standard_Transient):
    def Build(self) -> CDF_MetaDataDriver: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDF_Store():
    def AssociatedStatusText(self) -> str: ...
    def Comment(self) -> OCP.TCollection.TCollection_HExtendedString: ...
    def CurrentIsConsistent(self) -> bool: ...
    def Description(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        returns the description of the format of the main object.
        """
    def Folder(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        returns the folder in which the current document will be stored.
        """
    def HasAPreviousVersion(self) -> bool: ...
    def IsConsistent(self) -> bool: ...
    def IsMainDocument(self) -> bool: 
        """
        returns true if the currentdocument is the main one, ie the document of the current selection.
        """
    def IsModified(self) -> bool: ...
    def IsStored(self) -> bool: 
        """
        returns true if the current document is already stored
        """
    def MetaDataPath(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        returns the path of the previous store is the object is already stored, otherwise an empty string;
        """
    def Name(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        returns the name under which the current document will be stored
        """
    def Path(self) -> str: 
        """
        returns the complete path of the created meta-data.
        """
    def PreviousVersion(self) -> OCP.TCollection.TCollection_HExtendedString: ...
    def Realize(self,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    def RecheckName(self) -> CDF_StoreSetNameStatus: 
        """
        defines the name under which the document should be stored. uses for example after modification of the folder.
        """
    def SetComment(self,aComment : str) -> None: ...
    def SetCurrent(self,aPresentation : str) -> None: ...
    @overload
    def SetFolder(self,aFolder : OCP.TCollection.TCollection_ExtendedString) -> bool: 
        """
        defines the folder in which the document should be stored. returns Standard_True if the Folder exists, Standard_False otherwise.

        defines the folder in which the document should be stored. returns Standard_True if the Folder exists, Standard_False otherwise.
        """
    @overload
    def SetFolder(self,aFolder : str) -> bool: ...
    def SetMain(self) -> None: 
        """
        the two following methods can be used just after Realize or Import -- method to know if thes methods worked correctly, and if not why.
        """
    @overload
    def SetName(self,aName : str) -> CDF_StoreSetNameStatus: 
        """
        defines the name under which the document should be stored.

        defines the name under which the document should be stored.
        """
    @overload
    def SetName(self,aName : OCP.TCollection.TCollection_ExtendedString) -> CDF_StoreSetNameStatus: ...
    def SetPreviousVersion(self,aPreviousVersion : str) -> bool: ...
    def StoreStatus(self) -> OCP.PCDM.PCDM_StoreStatus: ...
    def __init__(self,aDocument : OCP.CDM.CDM_Document) -> None: ...
    pass
class CDF_StoreList(OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self) -> None: ...
    def IsConsistent(self) -> bool: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def More(self) -> bool: ...
    def Next(self) -> None: ...
    def Store(self,aMetaData : OCP.CDM.CDM_MetaData,aStatusAssociatedText : OCP.TCollection.TCollection_ExtendedString,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> OCP.PCDM.PCDM_StoreStatus: 
        """
        stores each object of the storelist in the reverse order of which they had been added.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Value(self) -> OCP.CDM.CDM_Document: ...
    def __init__(self,aDocument : OCP.CDM.CDM_Document) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDF_StoreSetNameStatus():
    """
    Members:

      CDF_SSNS_OK

      CDF_SSNS_ReplacingAnExistentDocument

      CDF_SSNS_OpenDocument
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CDF_SSNS_OK: OCP.CDF.CDF_StoreSetNameStatus # value = <CDF_StoreSetNameStatus.CDF_SSNS_OK: 0>
    CDF_SSNS_OpenDocument: OCP.CDF.CDF_StoreSetNameStatus # value = <CDF_StoreSetNameStatus.CDF_SSNS_OpenDocument: 2>
    CDF_SSNS_ReplacingAnExistentDocument: OCP.CDF.CDF_StoreSetNameStatus # value = <CDF_StoreSetNameStatus.CDF_SSNS_ReplacingAnExistentDocument: 1>
    __entries: dict # value = {'CDF_SSNS_OK': (<CDF_StoreSetNameStatus.CDF_SSNS_OK: 0>, None), 'CDF_SSNS_ReplacingAnExistentDocument': (<CDF_StoreSetNameStatus.CDF_SSNS_ReplacingAnExistentDocument: 1>, None), 'CDF_SSNS_OpenDocument': (<CDF_StoreSetNameStatus.CDF_SSNS_OpenDocument: 2>, None)}
    __members__: dict # value = {'CDF_SSNS_OK': <CDF_StoreSetNameStatus.CDF_SSNS_OK: 0>, 'CDF_SSNS_ReplacingAnExistentDocument': <CDF_StoreSetNameStatus.CDF_SSNS_ReplacingAnExistentDocument: 1>, 'CDF_SSNS_OpenDocument': <CDF_StoreSetNameStatus.CDF_SSNS_OpenDocument: 2>}
    pass
class CDF_SubComponentStatus():
    """
    Members:

      CDF_SCS_Consistent

      CDF_SCS_Unconsistent

      CDF_SCS_Stored

      CDF_SCS_Modified
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CDF_SCS_Consistent: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Consistent: 0>
    CDF_SCS_Modified: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Modified: 3>
    CDF_SCS_Stored: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Stored: 2>
    CDF_SCS_Unconsistent: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Unconsistent: 1>
    __entries: dict # value = {'CDF_SCS_Consistent': (<CDF_SubComponentStatus.CDF_SCS_Consistent: 0>, None), 'CDF_SCS_Unconsistent': (<CDF_SubComponentStatus.CDF_SCS_Unconsistent: 1>, None), 'CDF_SCS_Stored': (<CDF_SubComponentStatus.CDF_SCS_Stored: 2>, None), 'CDF_SCS_Modified': (<CDF_SubComponentStatus.CDF_SCS_Modified: 3>, None)}
    __members__: dict # value = {'CDF_SCS_Consistent': <CDF_SubComponentStatus.CDF_SCS_Consistent: 0>, 'CDF_SCS_Unconsistent': <CDF_SubComponentStatus.CDF_SCS_Unconsistent: 1>, 'CDF_SCS_Stored': <CDF_SubComponentStatus.CDF_SCS_Stored: 2>, 'CDF_SCS_Modified': <CDF_SubComponentStatus.CDF_SCS_Modified: 3>}
    pass
class CDF_TryStoreStatus():
    """
    Members:

      CDF_TS_OK

      CDF_TS_NoCurrentDocument

      CDF_TS_NoDriver

      CDF_TS_NoSubComponentDriver
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CDF_TS_NoCurrentDocument: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_NoCurrentDocument: 1>
    CDF_TS_NoDriver: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_NoDriver: 2>
    CDF_TS_NoSubComponentDriver: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_NoSubComponentDriver: 3>
    CDF_TS_OK: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_OK: 0>
    __entries: dict # value = {'CDF_TS_OK': (<CDF_TryStoreStatus.CDF_TS_OK: 0>, None), 'CDF_TS_NoCurrentDocument': (<CDF_TryStoreStatus.CDF_TS_NoCurrentDocument: 1>, None), 'CDF_TS_NoDriver': (<CDF_TryStoreStatus.CDF_TS_NoDriver: 2>, None), 'CDF_TS_NoSubComponentDriver': (<CDF_TryStoreStatus.CDF_TS_NoSubComponentDriver: 3>, None)}
    __members__: dict # value = {'CDF_TS_OK': <CDF_TryStoreStatus.CDF_TS_OK: 0>, 'CDF_TS_NoCurrentDocument': <CDF_TryStoreStatus.CDF_TS_NoCurrentDocument: 1>, 'CDF_TS_NoDriver': <CDF_TryStoreStatus.CDF_TS_NoDriver: 2>, 'CDF_TS_NoSubComponentDriver': <CDF_TryStoreStatus.CDF_TS_NoSubComponentDriver: 3>}
    pass
class CDF_TypeOfActivation():
    """
    Members:

      CDF_TOA_New

      CDF_TOA_Modified

      CDF_TOA_Unchanged
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CDF_TOA_Modified: OCP.CDF.CDF_TypeOfActivation # value = <CDF_TypeOfActivation.CDF_TOA_Modified: 1>
    CDF_TOA_New: OCP.CDF.CDF_TypeOfActivation # value = <CDF_TypeOfActivation.CDF_TOA_New: 0>
    CDF_TOA_Unchanged: OCP.CDF.CDF_TypeOfActivation # value = <CDF_TypeOfActivation.CDF_TOA_Unchanged: 2>
    __entries: dict # value = {'CDF_TOA_New': (<CDF_TypeOfActivation.CDF_TOA_New: 0>, None), 'CDF_TOA_Modified': (<CDF_TypeOfActivation.CDF_TOA_Modified: 1>, None), 'CDF_TOA_Unchanged': (<CDF_TypeOfActivation.CDF_TOA_Unchanged: 2>, None)}
    __members__: dict # value = {'CDF_TOA_New': <CDF_TypeOfActivation.CDF_TOA_New: 0>, 'CDF_TOA_Modified': <CDF_TypeOfActivation.CDF_TOA_Modified: 1>, 'CDF_TOA_Unchanged': <CDF_TypeOfActivation.CDF_TOA_Unchanged: 2>}
    pass
CDF_SCS_Consistent: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Consistent: 0>
CDF_SCS_Modified: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Modified: 3>
CDF_SCS_Stored: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Stored: 2>
CDF_SCS_Unconsistent: OCP.CDF.CDF_SubComponentStatus # value = <CDF_SubComponentStatus.CDF_SCS_Unconsistent: 1>
CDF_SSNS_OK: OCP.CDF.CDF_StoreSetNameStatus # value = <CDF_StoreSetNameStatus.CDF_SSNS_OK: 0>
CDF_SSNS_OpenDocument: OCP.CDF.CDF_StoreSetNameStatus # value = <CDF_StoreSetNameStatus.CDF_SSNS_OpenDocument: 2>
CDF_SSNS_ReplacingAnExistentDocument: OCP.CDF.CDF_StoreSetNameStatus # value = <CDF_StoreSetNameStatus.CDF_SSNS_ReplacingAnExistentDocument: 1>
CDF_TOA_Modified: OCP.CDF.CDF_TypeOfActivation # value = <CDF_TypeOfActivation.CDF_TOA_Modified: 1>
CDF_TOA_New: OCP.CDF.CDF_TypeOfActivation # value = <CDF_TypeOfActivation.CDF_TOA_New: 0>
CDF_TOA_Unchanged: OCP.CDF.CDF_TypeOfActivation # value = <CDF_TypeOfActivation.CDF_TOA_Unchanged: 2>
CDF_TS_NoCurrentDocument: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_NoCurrentDocument: 1>
CDF_TS_NoDriver: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_NoDriver: 2>
CDF_TS_NoSubComponentDriver: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_NoSubComponentDriver: 3>
CDF_TS_OK: OCP.CDF.CDF_TryStoreStatus # value = <CDF_TryStoreStatus.CDF_TS_OK: 0>



import OCP.BRepFilletAPI
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.BRepBuilderAPI
import OCP.ChFi2d
import OCP.Geom
import OCP.TopTools
import OCP.TColgp
import OCP.TopoDS
import OCP.Law
import OCP.ChFiDS
import OCP.GeomAbs
import OCP.TopOpeBRepBuild
import OCP.ChFi3d
__all__  = [
"BRepFilletAPI_LocalOperation",
"BRepFilletAPI_MakeChamfer",
"BRepFilletAPI_MakeFillet",
"BRepFilletAPI_MakeFillet2d"
]
class BRepFilletAPI_LocalOperation(OCP.BRepBuilderAPI.BRepBuilderAPI_MakeShape, OCP.BRepBuilderAPI.BRepBuilderAPI_Command):
    """
    Construction of fillets on the edges of a Shell.
    """
    def Abscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        returns the abscissa of the vertex V on the contour of index IC.
        """
    def Add(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Adds a contour in the builder (builds a contour of tangent edges).
        """
    def Build(self,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        This is called by Shape(). It does nothing but may be redefined.
        """
    def Check(self) -> None: 
        """
        Raises NotDone if done is false.
        """
    def Closed(self,IC : int) -> bool: 
        """
        returns true if the contour of index IC is closed
        """
    def ClosedAndTangent(self,IC : int) -> bool: 
        """
        returns true if the contour of index IC is closed an tangent.
        """
    def Contour(self,E : OCP.TopoDS.TopoDS_Edge) -> int: 
        """
        Returns the index of the contour containing the edge E, returns 0 if E doesn't belong to any contour.
        """
    def Edge(self,I : int,J : int) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Returns the Edge J in the contour I.
        """
    def FirstVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the first Vertex of the contour of index IC.
        """
    def Generated(self,S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes generated from the shape <S>.
        """
    def IsDeleted(self,S : OCP.TopoDS.TopoDS_Shape) -> bool: 
        """
        Returns true if the shape S has been deleted.
        """
    def IsDone(self) -> bool: ...
    def LastVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the last Vertex of the contour of index IC.
        """
    def Length(self,IC : int) -> float: 
        """
        returns the length the contour of index IC.
        """
    def Modified(self,S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes modified from the shape <S>.
        """
    def NbContours(self) -> int: 
        """
        Number of contours.
        """
    def NbEdges(self,I : int) -> int: 
        """
        Number of Edges in the contour I.
        """
    def NbSurf(self,IC : int) -> int: ...
    def RelativeAbscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        returns the relative abscissa([0.,1.]) of the vertex V on the contour of index IC.
        """
    def Remove(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        remove the contour containing the Edge E.
        """
    def Reset(self) -> None: 
        """
        Reset all the fields updated by Build operation and leave the algorithm in the same state than before build call. It allows contours and radius modifications to build the result another time.
        """
    def ResetContour(self,IC : int) -> None: 
        """
        Reset the contour of index IC, there is nomore information in the contour.
        """
    def Sect(self,IC : int,IS : int) -> OCP.ChFiDS.ChFiDS_SecHArray1: ...
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a shape built by the shape construction algorithm. Raises exception StdFail_NotDone if the shape was not built.
        """
    def Simulate(self,IC : int) -> None: ...
    def __bool__(self) -> bool: 
        """
        Check if command is done
        """
    pass
class BRepFilletAPI_MakeChamfer(BRepFilletAPI_LocalOperation, OCP.BRepBuilderAPI.BRepBuilderAPI_MakeShape, OCP.BRepBuilderAPI.BRepBuilderAPI_Command):
    """
    Describes functions to build chamfers on edges of a shell or solid. Chamfered Edge of a Shell or Solid A MakeChamfer object provides a framework for: - initializing the construction algorithm with a given shape, - acquiring the data characterizing the chamfers, - building the chamfers and constructing the resulting shape, and - consulting the result.
    """
    def Abscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        Returns the curvilinear abscissa of the vertex V on the contour of index IC in the internal data structure of this algorithm. Warning Returns -1. if: - IC is outside the bounds of the table of contours, or - V is not on the contour of index IC.
        """
    @overload
    def Add(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Adds edge E to the table of edges used by this algorithm to build chamfers, where the parameters of the chamfer must be set after the

        Adds edge E to the table of edges used by this algorithm to build chamfers, where the parameters of the chamfer are given by the distance Dis (symmetric chamfer). The Add function results in a contour being built by propagation from the edge E (i.e. the contour contains at least this edge). This contour is composed of edges of the shape which are tangential to one another and which delimit two series of tangential faces, with one series of faces being located on either side of the contour. Warning Nothing is done if edge E or the face F does not belong to the initial shape.

        Adds edge E to the table of edges used by this algorithm to build chamfers, where the parameters of the chamfer are given by the two distances Dis1 and Dis2; the face F identifies the side where Dis1 is measured. The Add function results in a contour being built by propagation from the edge E (i.e. the contour contains at least this edge). This contour is composed of edges of the shape which are tangential to one another and which delimit two series of tangential faces, with one series of faces being located on either side of the contour. Warning Nothing is done if edge E or the face F does not belong to the initial shape.
        """
    @overload
    def Add(self,Dis : float,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @overload
    def Add(self,Dis1 : float,Dis2 : float,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face) -> None: ...
    def AddDA(self,Dis : float,Angle : float,E : OCP.TopoDS.TopoDS_Edge,F : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Adds a fillet contour in the builder (builds a contour of tangent edges to <E> and sets the distance <Dis1> and angle <Angle> ( parameters of the chamfer ) ).
        """
    def Build(self,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        Builds the chamfers on all the contours in the internal data structure of this algorithm and constructs the resulting shape. Use the function IsDone to verify that the chamfered shape is built. Use the function Shape to retrieve the chamfered shape. Warning The construction of chamfers implements highly complex construction algorithms. Consequently, there may be instances where the algorithm fails, for example if the data defining the parameters of the chamfer is not compatible with the geometry of the initial shape. There is no initial analysis of errors and these only become evident at the construction stage. Additionally, in the current software release, the following cases are not handled: - the end point of the contour is the point of intersection of 4 or more edges of the shape, or - the intersection of the chamfer with a face which limits the contour is not fully contained in this face.
        """
    def Builder(self) -> OCP.TopOpeBRepBuild.TopOpeBRepBuild_HBuilder: 
        """
        Returns the internal filleting algorithm.
        """
    def Check(self) -> None: 
        """
        Raises NotDone if done is false.
        """
    def Closed(self,IC : int) -> bool: 
        """
        Returns true if the contour of index IC in the internal data structure of this algorithm is closed. Warning Returns false if IC is outside the bounds of the table of contours.
        """
    def ClosedAndTangent(self,IC : int) -> bool: 
        """
        eturns true if the contour of index IC in the internal data structure of this algorithm is closed and tangential at the point of closure. Warning Returns false if IC is outside the bounds of the table of contours.
        """
    def Contour(self,E : OCP.TopoDS.TopoDS_Edge) -> int: 
        """
        Returns the index of the contour in the internal data structure of this algorithm, which contains the edge E of the shape. This function returns 0 if the edge E does not belong to any contour. Warning This index can change if a contour is removed from the internal data structure of this algorithm using the function Remove.
        """
    def Dists(self,IC : int) -> tuple[float, float]: 
        """
        Returns the distances Dis1 and Dis2 which give the parameters of the chamfer along the contour of index IC in the internal data structure of this algorithm. Warning -1. is returned if IC is outside the bounds of the table of contours.
        """
    def Edge(self,I : int,J : int) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Returns the edge of index J in the contour of index I in the internal data structure of this algorithm. Warning Returns a null shape if: - I is outside the bounds of the table of contours, or - J is outside the bounds of the table of edges of the contour of index I.
        """
    def FirstVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the first vertex of the contour of index IC in the internal data structure of this algorithm. Warning Returns a null shape if IC is outside the bounds of the table of contours.
        """
    def Generated(self,EorV : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes generated from the shape <EorV>.
        """
    def GetDist(self,IC : int) -> tuple[float]: ...
    def GetDistAngle(self,IC : int) -> tuple[float, float]: 
        """
        gives the distances <Dis> and <Angle> of the fillet contour of index <IC> in the DS
        """
    def IsDeleted(self,F : OCP.TopoDS.TopoDS_Shape) -> bool: ...
    def IsDistanceAngle(self,IC : int) -> bool: 
        """
        return True if chamfer is made with distance and angle false else.
        """
    def IsDone(self) -> bool: ...
    def IsSymetric(self,IC : int) -> bool: 
        """
        return True if chamfer symmetric false else.
        """
    def IsTwoDistances(self,IC : int) -> bool: 
        """
        return True if chamfer is made with two distances false else.
        """
    def LastVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the last vertex of the contour of index IC in the internal data structure of this algorithm. Warning Returns a null shape if IC is outside the bounds of the table of contours.
        """
    def Length(self,IC : int) -> float: 
        """
        Returns the length of the contour of index IC in the internal data structure of this algorithm. Warning Returns -1. if IC is outside the bounds of the table of contours.
        """
    def Modified(self,F : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes modified from the shape <F>.
        """
    def NbContours(self) -> int: 
        """
        Returns the number of contours generated using the Add function in the internal data structure of this algorithm.
        """
    def NbEdges(self,I : int) -> int: 
        """
        Returns the number of edges in the contour of index I in the internal data structure of this algorithm. Warning Returns 0 if I is outside the bounds of the table of contours.
        """
    def NbSurf(self,IC : int) -> int: ...
    def RelativeAbscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        Returns the relative curvilinear abscissa (i.e. between 0 and 1) of the vertex V on the contour of index IC in the internal data structure of this algorithm. Warning Returns -1. if: - IC is outside the bounds of the table of contours, or - V is not on the contour of index IC.
        """
    def Remove(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Removes the contour in the internal data structure of this algorithm which contains the edge E of the shape. Warning Nothing is done if the edge E does not belong to the contour in the internal data structure of this algorithm.
        """
    def Reset(self) -> None: 
        """
        Reinitializes this algorithm, thus canceling the effects of the Build function. This function allows modifications to be made to the contours and chamfer parameters in order to rebuild the shape.
        """
    def ResetContour(self,IC : int) -> None: 
        """
        Erases the chamfer parameters on the contour of index IC in the internal data structure of this algorithm. Use the SetDists function to reset this data. Warning Nothing is done if IC is outside the bounds of the table of contours.
        """
    def Sect(self,IC : int,IS : int) -> OCP.ChFiDS.ChFiDS_SecHArray1: ...
    def SetDist(self,Dis : float,IC : int,F : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Sets the distances Dis1 and Dis2 which give the parameters of the chamfer along the contour of index IC generated using the Add function in the internal data structure of this algorithm. The face F identifies the side where Dis1 is measured. Warning Nothing is done if either the edge E or the face F does not belong to the initial shape.
        """
    def SetDistAngle(self,Dis : float,Angle : float,IC : int,F : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        set the distance <Dis> and <Angle> of the fillet contour of index <IC> in the DS with <Dis> on <F>. if the face <F> is not one of common faces of an edge of the contour <IC>
        """
    def SetDists(self,Dis1 : float,Dis2 : float,IC : int,F : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Sets the distances Dis1 and Dis2 which give the parameters of the chamfer along the contour of index IC generated using the Add function in the internal data structure of this algorithm. The face F identifies the side where Dis1 is measured. Warning Nothing is done if either the edge E or the face F does not belong to the initial shape.
        """
    def SetMode(self,theMode : OCP.ChFiDS.ChFiDS_ChamfMode) -> None: 
        """
        Sets the mode of chamfer
        """
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a shape built by the shape construction algorithm. Raises exception StdFail_NotDone if the shape was not built.
        """
    def Simulate(self,IC : int) -> None: ...
    def __bool__(self) -> bool: 
        """
        Check if command is done
        """
    def __init__(self,S : OCP.TopoDS.TopoDS_Shape) -> None: ...
    pass
class BRepFilletAPI_MakeFillet(BRepFilletAPI_LocalOperation, OCP.BRepBuilderAPI.BRepBuilderAPI_MakeShape, OCP.BRepBuilderAPI.BRepBuilderAPI_Command):
    """
    Describes functions to build fillets on the broken edges of a shell or solid. A MakeFillet object provides a framework for: - initializing the construction algorithm with a given shape, - acquiring the data characterizing the fillets, - building the fillets and constructing the resulting shape, and - consulting the result.
    """
    def Abscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        Returns the curvilinear abscissa of the vertex V on the contour of index IC in the internal data structure of this algorithm. Warning Returns -1. if: - IC is outside the bounds of the table of contours, or - V is not on the contour of index IC.
        """
    @overload
    def Add(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Adds a fillet contour in the builder (builds a contour of tangent edges). The Radius must be set after.

        Adds a fillet description in the builder - builds a contour of tangent edges, - sets the radius.

        Adds a fillet description in the builder - builds a contour of tangent edges, - sets a linear radius evolution law between the first and last vertex of the spine.

        Adds a fillet description in the builder - builds a contour of tangent edges, - sest the radius evolution law.

        Adds a fillet description in the builder - builds a contour of tangent edges, - sets the radius evolution law interpolating the values given in the array UandR :
        """
    @overload
    def Add(self,Radius : float,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @overload
    def Add(self,R1 : float,R2 : float,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @overload
    def Add(self,L : OCP.Law.Law_Function,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @overload
    def Add(self,UandR : OCP.TColgp.TColgp_Array1OfPnt2d,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    def BadShape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        if (HasResult()) returns the partial result
        """
    def Build(self,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        Builds the fillets on all the contours in the internal data structure of this algorithm and constructs the resulting shape. Use the function IsDone to verify that the filleted shape is built. Use the function Shape to retrieve the filleted shape. Warning The construction of fillets implements highly complex construction algorithms. Consequently, there may be instances where the algorithm fails, for example if the data defining the radius of the fillet is not compatible with the geometry of the initial shape. There is no initial analysis of errors and they only become evident at the construction stage. Additionally, in the current software release, the following cases are not handled: - the end point of the contour is the point of intersection of 4 or more edges of the shape, or - the intersection of the fillet with a face which limits the contour is not fully contained in this face.
        """
    def Builder(self) -> OCP.TopOpeBRepBuild.TopOpeBRepBuild_HBuilder: 
        """
        Returns the internal topology building algorithm.
        """
    def Check(self) -> None: 
        """
        Raises NotDone if done is false.
        """
    def Closed(self,IC : int) -> bool: 
        """
        Returns true if the contour of index IC in the internal data structure of this algorithm is closed. Warning Returns false if IC is outside the bounds of the table of contours.
        """
    def ClosedAndTangent(self,IC : int) -> bool: 
        """
        Returns true if the contour of index IC in the internal data structure of this algorithm is closed and tangential at the point of closure. Warning Returns false if IC is outside the bounds of the table of contours.
        """
    def ComputedSurface(self,IC : int,IS : int) -> OCP.Geom.Geom_Surface: 
        """
        returns the surface number IS concerning the contour IC
        """
    def Contour(self,E : OCP.TopoDS.TopoDS_Edge) -> int: 
        """
        Returns the index of the contour in the internal data structure of this algorithm which contains the edge E of the shape. This function returns 0 if the edge E does not belong to any contour. Warning This index can change if a contour is removed from the internal data structure of this algorithm using the function Remove.
        """
    def Edge(self,I : int,J : int) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Returns the edge of index J in the contour of index I in the internal data structure of this algorithm. Warning Returns a null shape if: - I is outside the bounds of the table of contours, or - J is outside the bounds of the table of edges of the index I contour.
        """
    def FaultyContour(self,I : int) -> int: 
        """
        for each I in [1.. NbFaultyContours] returns the index IC of the contour where the computation of the fillet failed. the method NbEdges(IC) gives the number of edges in the contour IC the method Edge(IC,ie) gives the edge number ie of the contour IC
        """
    def FaultyVertex(self,IV : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        returns the vertex where the computation failed
        """
    def FirstVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the first vertex of the contour of index IC in the internal data structure of this algorithm. Warning Returns a null shape if IC is outside the bounds of the table of contours.
        """
    def Generated(self,EorV : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes generated from the shape <EorV>.
        """
    def GetBounds(self,IC : int,E : OCP.TopoDS.TopoDS_Edge,F : float,L : float) -> bool: ...
    def GetFilletShape(self) -> OCP.ChFi3d.ChFi3d_FilletShape: 
        """
        Returns the type of fillet shape built by this algorithm.
        """
    def GetLaw(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> OCP.Law.Law_Function: ...
    def HasResult(self) -> bool: 
        """
        returns true if a part of the result has been computed if the filling in a corner failed a shape with a hole is returned
        """
    @overload
    def IsConstant(self,IC : int) -> bool: 
        """
        Returns true if the radius of the fillet along the contour of index IC in the internal data structure of this algorithm is constant, Warning False is returned if IC is outside the bounds of the table of contours or if E does not belong to the contour of index IC.

        Returns true if the radius of the fillet along the edge E of the contour of index IC in the internal data structure of this algorithm is constant. Warning False is returned if IC is outside the bounds of the table of contours or if E does not belong to the contour of index IC.
        """
    @overload
    def IsConstant(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> bool: ...
    def IsDeleted(self,F : OCP.TopoDS.TopoDS_Shape) -> bool: ...
    def IsDone(self) -> bool: ...
    def LastVertex(self,IC : int) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Returns the last vertex of the contour of index IC in the internal data structure of this algorithm. Warning Returns a null shape if IC is outside the bounds of the table of contours.
        """
    def Length(self,IC : int) -> float: 
        """
        Returns the length of the contour of index IC in the internal data structure of this algorithm. Warning Returns -1. if IC is outside the bounds of the table of contours.
        """
    def Modified(self,F : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes modified from the shape <F>.
        """
    def NbComputedSurfaces(self,IC : int) -> int: 
        """
        returns the number of surfaces which have been computed on the contour IC
        """
    def NbContours(self) -> int: 
        """
        Returns the number of contours generated using the Add function in the internal data structure of this algorithm.
        """
    def NbEdges(self,I : int) -> int: 
        """
        Returns the number of edges in the contour of index I in the internal data structure of this algorithm. Warning Returns 0 if I is outside the bounds of the table of contours.
        """
    def NbFaultyContours(self) -> int: 
        """
        Returns the number of contours where the computation of the fillet failed
        """
    def NbFaultyVertices(self) -> int: 
        """
        returns the number of vertices where the computation failed
        """
    def NbSurf(self,IC : int) -> int: ...
    def NbSurfaces(self) -> int: 
        """
        returns the number of surfaces after the shape creation.
        """
    def NewFaces(self,I : int) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Return the faces created for surface <I>.
        """
    @overload
    def Radius(self,IC : int) -> float: 
        """
        Returns the radius of the fillet along the contour of index IC in the internal data structure of this algorithm Warning - Use this function only if the radius is constant. - -1. is returned if IC is outside the bounds of the table of contours or if E does not belong to the contour of index IC.

        Returns the radius of the fillet along the edge E of the contour of index IC in the internal data structure of this algorithm. Warning - Use this function only if the radius is constant. - -1 is returned if IC is outside the bounds of the table of contours or if E does not belong to the contour of index IC.
        """
    @overload
    def Radius(self,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> float: ...
    def RelativeAbscissa(self,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> float: 
        """
        Returns the relative curvilinear abscissa (i.e. between 0 and 1) of the vertex V on the contour of index IC in the internal data structure of this algorithm. Warning Returns -1. if: - IC is outside the bounds of the table of contours, or - V is not on the contour of index IC.
        """
    def Remove(self,E : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Removes the contour in the internal data structure of this algorithm which contains the edge E of the shape. Warning Nothing is done if the edge E does not belong to the contour in the internal data structure of this algorithm.
        """
    def Reset(self) -> None: 
        """
        Reinitializes this algorithm, thus canceling the effects of the Build function. This function allows modifications to be made to the contours and fillet parameters in order to rebuild the shape.
        """
    def ResetContour(self,IC : int) -> None: 
        """
        Erases the radius information on the contour of index IC in the internal data structure of this algorithm. Use the SetRadius function to reset this data. Warning Nothing is done if IC is outside the bounds of the table of contours.
        """
    def Sect(self,IC : int,IS : int) -> OCP.ChFiDS.ChFiDS_SecHArray1: ...
    def SetContinuity(self,InternalContinuity : OCP.GeomAbs.GeomAbs_Shape,AngularTolerance : float) -> None: 
        """
        Changes the parameters of continiuity InternalContinuity to produce fillet'surfaces with an continuity Ci (i=0,1 or 2). By defaultInternalContinuity = GeomAbs_C1. AngularTolerance is the G1 tolerance between fillet and support'faces.
        """
    def SetFilletShape(self,FShape : OCP.ChFi3d.ChFi3d_FilletShape) -> None: 
        """
        Assigns FShape as the type of fillet shape built by this algorithm.
        """
    def SetLaw(self,IC : int,E : OCP.TopoDS.TopoDS_Edge,L : OCP.Law.Law_Function) -> None: ...
    def SetParams(self,Tang : float,Tesp : float,T2d : float,TApp3d : float,TolApp2d : float,Fleche : float) -> None: ...
    @overload
    def SetRadius(self,Radius : float,IC : int,IinC : int) -> None: 
        """
        Sets the parameters of the fillet along the contour of index IC generated using the Add function in the internal data structure of this algorithm, where Radius is the radius of the fillet.

        Sets the parameters of the fillet along the contour of index IC generated using the Add function in the internal data structure of this algorithm, where the radius of the fillet evolves according to a linear evolution law defined from R1 to R2, between the first and last vertices of the contour of index IC.

        Sets the parameters of the fillet along the contour of index IC generated using the Add function in the internal data structure of this algorithm, where the radius of the fillet evolves according to the evolution law L, between the first and last vertices of the contour of index IC.

        Sets the parameters of the fillet along the contour of index IC generated using the Add function in the internal data structure of this algorithm, where the radius of the fillet evolves according to the evolution law which interpolates the set of parameter and radius pairs given in the array UandR as follows: - the X coordinate of a point in UandR defines a relative parameter on the contour (i.e. a parameter between 0 and 1), - the Y coordinate of a point in UandR gives the corresponding value of the radius, and the radius evolves between the first and last vertices of the contour of index IC.

        Assigns Radius as the radius of the fillet on the edge E
        """
    @overload
    def SetRadius(self,R1 : float,R2 : float,IC : int,IinC : int) -> None: ...
    @overload
    def SetRadius(self,L : OCP.Law.Law_Function,IC : int,IinC : int) -> None: ...
    @overload
    def SetRadius(self,UandR : OCP.TColgp.TColgp_Array1OfPnt2d,IC : int,IinC : int) -> None: ...
    @overload
    def SetRadius(self,Radius : float,IC : int,E : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @overload
    def SetRadius(self,Radius : float,IC : int,V : OCP.TopoDS.TopoDS_Vertex) -> None: ...
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a shape built by the shape construction algorithm. Raises exception StdFail_NotDone if the shape was not built.
        """
    def Simulate(self,IC : int) -> None: ...
    def StripeStatus(self,IC : int) -> OCP.ChFiDS.ChFiDS_ErrorStatus: 
        """
        returns the status concerning the contour IC in case of error ChFiDS_Ok : the computation is Ok ChFiDS_StartsolFailure : the computation can't start, perhaps the the radius is too big ChFiDS_TwistedSurface : the computation failed because of a twisted surface ChFiDS_WalkingFailure : there is a problem in the walking ChFiDS_Error: other error different from above
        """
    def __bool__(self) -> bool: 
        """
        Check if command is done
        """
    def __init__(self,S : OCP.TopoDS.TopoDS_Shape,FShape : OCP.ChFi3d.ChFi3d_FilletShape=ChFi3d_FilletShape.ChFi3d_Rational) -> None: ...
    pass
class BRepFilletAPI_MakeFillet2d(OCP.BRepBuilderAPI.BRepBuilderAPI_MakeShape, OCP.BRepBuilderAPI.BRepBuilderAPI_Command):
    """
    Describes functions to build fillets and chamfers on the vertices of a planar face. Fillets and Chamfers on the Vertices of a Planar Face A MakeFillet2d object provides a framework for: - initializing the construction algorithm with a given face, - acquiring the data characterizing the fillets and chamfers, - building the fillets and chamfers, and constructing the resulting shape, and - consulting the result. Warning Only segments of straight lines and arcs of circles are treated. BSplines are not processed.
    """
    @overload
    def AddChamfer(self,E1 : OCP.TopoDS.TopoDS_Edge,E2 : OCP.TopoDS.TopoDS_Edge,D1 : float,D2 : float) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Adds a chamfer on the face modified by this algorithm between the two adjacent edges E1 and E2, where the extremities of the chamfer are on E1 and E2 at distances D1 and D2 respectively In cases where the edges are not rectilinear, distances are measured using the curvilinear abscissa of the edges and the angle is measured with respect to the tangent at the corresponding point. The angle Ang is given in radians. This function returns the chamfer and builds the resulting face.

        Adds a chamfer on the face modified by this algorithm between the two edges connected by the vertex V, where E is one of the two edges. The chamfer makes an angle Ang with E and one of its extremities is on E at distance D from V. In cases where the edges are not rectilinear, distances are measured using the curvilinear abscissa of the edges and the angle is measured with respect to the tangent at the corresponding point. The angle Ang is given in radians. This function returns the chamfer and builds the resulting face. Warning The status of the construction, as given by the Status function, can be one of the following: - ChFi2d_IsDone if the chamfer is built, - ChFi2d_ParametersError if D1, D2, D or Ang is less than or equal to zero, - ChFi2d_ConnexionError if: - the edge E, E1 or E2 does not belong to the initial face, or - the edges E1 and E2 are not adjacent, or - the vertex V is not one of the limit points of the edge E, - ChFi2d_ComputationError if the parameters of the chamfer are too large to build a chamfer between the two adjacent edges, - ChFi2d_NotAuthorized if: - the edge E1, E2 or one of the two edges connected to V is a fillet or chamfer, or - a curve other than a straight line or an arc of a circle is used as E, E1 or E2. Do not use the returned chamfer if the status of the construction is not ChFi2d_IsDone.
        """
    @overload
    def AddChamfer(self,E : OCP.TopoDS.TopoDS_Edge,V : OCP.TopoDS.TopoDS_Vertex,D : float,Ang : float) -> OCP.TopoDS.TopoDS_Edge: ...
    def AddFillet(self,V : OCP.TopoDS.TopoDS_Vertex,Radius : float) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Adds a fillet of radius Radius between the two edges adjacent to the vertex V on the face modified by this algorithm. The two edges do not need to be rectilinear. This function returns the fillet and builds the resulting face. Warning The status of the construction, as given by the Status function, can be one of the following: - ChFi2d_IsDone if the fillet is built, - ChFi2d_ConnexionError if V does not belong to the initial face, - ChFi2d_ComputationError if Radius is too large to build a fillet between the two adjacent edges, - ChFi2d_NotAuthorized - if one of the two edges connected to V is a fillet or chamfer, or - if a curve other than a straight line or an arc of a circle is used as E, E1 or E2. Do not use the returned fillet if the status of the construction is not ChFi2d_IsDone. Exceptions Standard_NegativeValue if Radius is less than or equal to zero.
        """
    def BasisEdge(self,E : OCP.TopoDS.TopoDS_Edge) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Returns the basis edge on the face modified by this algorithm from which the chamfered or filleted edge E is built. If E has not been modified, this function returns E. Warning E is returned if it does not belong to the initial face.
        """
    def Build(self,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        Update the result and set the Done flag
        """
    def ChamferEdges(self) -> OCP.TopTools.TopTools_SequenceOfShape: 
        """
        Returns the table of chamfers on the face modified by this algorithm.

        Returns the table of chamfers on the face modified by this algorithm.
        """
    def Check(self) -> None: 
        """
        Raises NotDone if done is false.
        """
    def DescendantEdge(self,E : OCP.TopoDS.TopoDS_Edge) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Returns the chamfered or filleted edge built from the edge E on the face modified by this algorithm. If E has not been modified, this function returns E. Exceptions Standard_NoSuchObject if the edge E does not belong to the initial face.

        Returns the chamfered or filleted edge built from the edge E on the face modified by this algorithm. If E has not been modified, this function returns E. Exceptions Standard_NoSuchObject if the edge E does not belong to the initial face.
        """
    def FilletEdges(self) -> OCP.TopTools.TopTools_SequenceOfShape: 
        """
        Returns the table of fillets on the face modified by this algorithm.

        Returns the table of fillets on the face modified by this algorithm.
        """
    def Generated(self,S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes generated from the shape <S>.
        """
    def HasDescendant(self,E : OCP.TopoDS.TopoDS_Edge) -> bool: ...
    @overload
    def Init(self,F : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Initializes this algorithm for constructing fillets or chamfers with the face F. Warning The status of the initialization, as given by the Status function, can be one of the following: - ChFi2d_Ready if the initialization is correct, - ChFi2d_NotPlanar if F is not planar, - ChFi2d_NoFace if F is a null face.

        This initialize method allow to init the builder from a face RefFace and another face ModFace which derive from RefFace. This is useful to modify a fillet or a chamfer already created on ModFace.
        """
    @overload
    def Init(self,RefFace : OCP.TopoDS.TopoDS_Face,ModFace : OCP.TopoDS.TopoDS_Face) -> None: ...
    def IsDeleted(self,S : OCP.TopoDS.TopoDS_Shape) -> bool: 
        """
        Returns true if the shape S has been deleted.
        """
    def IsDone(self) -> bool: ...
    def IsModified(self,E : OCP.TopoDS.TopoDS_Edge) -> bool: 
        """
        Returns true if the edge E on the face modified by this algorithm is chamfered or filleted. Warning Returns false if E does not belong to the face modified by this algorithm.

        Returns true if the edge E on the face modified by this algorithm is chamfered or filleted. Warning Returns false if E does not belong to the face modified by this algorithm.
        """
    def Modified(self,S : OCP.TopoDS.TopoDS_Shape) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Returns the list of shapes modified from the shape <S>.
        """
    @overload
    def ModifyChamfer(self,Chamfer : OCP.TopoDS.TopoDS_Edge,E1 : OCP.TopoDS.TopoDS_Edge,E2 : OCP.TopoDS.TopoDS_Edge,D1 : float,D2 : float) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Modifies the chamfer Chamfer on the face modified by this algorithm, where: E1 and E2 are the two adjacent edges on which Chamfer is already built; the extremities of the new chamfer are on E1 and E2 at distances D1 and D2 respectively.

        Modifies the chamfer Chamfer on the face modified by this algorithm, where: E is one of the two adjacent edges on which Chamfer is already built; the new chamfer makes an angle Ang with E and one of its extremities is on E at distance D from the vertex on which the chamfer is built. In cases where the edges are not rectilinear, the distances are measured using the curvilinear abscissa of the edges and the angle is measured with respect to the tangent at the corresponding point. The angle Ang is given in radians. This function returns the new chamfer and modifies the existing face. Warning The status of the construction, as given by the Status function, can be one of the following: - ChFi2d_IsDone if the chamfer is built, - ChFi2d_ParametersError if D1, D2, D or Ang is less than or equal to zero, - ChFi2d_ConnexionError if: - the edge E, E1, E2 or Chamfer does not belong to the existing face, or - the edges E1 and E2 are not adjacent, - ChFi2d_ComputationError if the parameters of the chamfer are too large to build a chamfer between the two adjacent edges, - ChFi2d_NotAuthorized if E1 or E2 is a fillet or chamfer. Do not use the returned chamfer if the status of the construction is not ChFi2d_IsDone.
        """
    @overload
    def ModifyChamfer(self,Chamfer : OCP.TopoDS.TopoDS_Edge,E : OCP.TopoDS.TopoDS_Edge,D : float,Ang : float) -> OCP.TopoDS.TopoDS_Edge: ...
    def ModifyFillet(self,Fillet : OCP.TopoDS.TopoDS_Edge,Radius : float) -> OCP.TopoDS.TopoDS_Edge: 
        """
        Assigns the radius Radius to the fillet Fillet already built on the face modified by this algorithm. This function returns the new fillet and modifies the existing face. Warning The status of the construction, as given by the Status function, can be one of the following: - ChFi2d_IsDone if the new fillet is built, - ChFi2d_ConnexionError if Fillet does not belong to the existing face, - ChFi2d_ComputationError if Radius is too large to build a fillet between the two adjacent edges. Do not use the returned fillet if the status of the construction is not ChFi2d_IsDone. Exceptions Standard_NegativeValue if Radius is less than or equal to zero.
        """
    def NbChamfer(self) -> int: 
        """
        Returns the number of chamfers on the face modified by this algorithm.

        Returns the number of chamfers on the face modified by this algorithm.
        """
    def NbCurves(self) -> int: 
        """
        returns the number of new curves after the shape creation.
        """
    def NbFillet(self) -> int: 
        """
        Returns the number of fillets on the face modified by this algorithm.

        Returns the number of fillets on the face modified by this algorithm.
        """
    def NewEdges(self,I : int) -> OCP.TopTools.TopTools_ListOfShape: 
        """
        Return the Edges created for curve I.
        """
    def RemoveChamfer(self,Chamfer : OCP.TopoDS.TopoDS_Edge) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Removes the chamfer Chamfer already built on the face modified by this algorithm. This function returns the vertex connecting the two adjacent edges of Chamfer and modifies the existing face. Warning - The returned vertex is only valid if the Status function returns ChFi2d_IsDone. - A null vertex is returned if the edge Chamfer does not belong to the initial face.
        """
    def RemoveFillet(self,Fillet : OCP.TopoDS.TopoDS_Edge) -> OCP.TopoDS.TopoDS_Vertex: 
        """
        Removes the fillet Fillet already built on the face modified by this algorithm. This function returns the vertex connecting the two adjacent edges of Fillet and modifies the existing face. Warning - The returned vertex is only valid if the Status function returns ChFi2d_IsDone. - A null vertex is returned if the edge Fillet does not belong to the initial face.
        """
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns a shape built by the shape construction algorithm. Raises exception StdFail_NotDone if the shape was not built.
        """
    def Status(self) -> OCP.ChFi2d.ChFi2d_ConstructionError: ...
    def __bool__(self) -> bool: 
        """
        Check if command is done
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,F : OCP.TopoDS.TopoDS_Face) -> None: ...
    pass



import OCP.StdObjMgt
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import OCP.Storage
import OCP.Standard
import OCP.TDocStd
import OCP.TDF
__all__  = [
"StdObjMgt_MapOfInstantiators",
"StdObjMgt_Persistent",
"StdObjMgt_ReadData",
"StdObjMgt_SharedObject",
"StdObjMgt_WriteData"
]
class StdObjMgt_MapOfInstantiators():
    def __init__(self) -> None: ...
    pass
class StdObjMgt_Persistent(OCP.Standard.Standard_Transient):
    """
    Root class for a temporary persistent object that reads data from a file and then creates transient object using the data.
    """
    def AsciiString(self) -> OCP.TCollection.TCollection_HAsciiString: 
        """
        Get referenced ASCII string (to be overridden by ASCII string class; returns a null handle by default for other classes).
        """
    def CreateAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Create an empty transient attribute (to be overridden by attribute classes; does nothing and returns a null handle by default for other classes).
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns a type descriptor about this object.
        """
    def ExtString(self) -> OCP.TCollection.TCollection_HExtendedString: 
        """
        Get referenced extended string (to be overridden by extended string class; returns a null handle by default for other classes).
        """
    def GetAttribute(self) -> OCP.TDF.TDF_Attribute: 
        """
        Get transient attribute for the persistent data (to be overridden by attribute classes; returns a null handle by default for non-attribute classes).
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def ImportAttribute(self) -> None: 
        """
        Import transient attribute from the persistent data (to be overridden by attribute classes; does nothing by default for non-attribute classes).
        """
    def ImportDocument(self,theDocument : OCP.TDocStd.TDocStd_Document) -> None: 
        """
        Import transient document from the persistent data (to be overridden by document class; does nothing by default for other classes).
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Label(self,theDF : OCP.TDF.TDF_Data) -> OCP.TDF.TDF_Label: 
        """
        Get a label expressed by referenced extended string (to be overridden by extended string class; returns a null label by default for other classes).
        """
    def PChildren(self,arg0 : Any) -> None: 
        """
        Gets persistent child objects
        """
    def PName(self) -> str: 
        """
        Returns persistent type name
        """
    def Read(self,theReadData : StdObjMgt_ReadData) -> None: 
        """
        Read persistent data from a file.
        """
    @overload
    def RefNum(self) -> int: 
        """
        Returns the object reference number

        Sets an object reference number
        """
    @overload
    def RefNum(self,theRefNum : int) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def TypeNum(self) -> int: 
        """
        Returns the assigned persistent type number

        Assigns a persistent type number to the object
        """
    @overload
    def TypeNum(self,theTypeNum : int) -> None: ...
    def Write(self,theWriteData : StdObjMgt_WriteData) -> None: 
        """
        Write persistent data to a file.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: 
        """
        Returns type descriptor of Standard_Transient class
        """
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class StdObjMgt_ReadData():
    """
    Auxiliary data used to read persistent objects from a file.
    """
    def PersistentObject(self,theRef : int) -> StdObjMgt_Persistent: ...
    def ReadPersistentObject(self,theRef : int) -> None: ...
    def ReadReference(self) -> StdObjMgt_Persistent: ...
    def __init__(self,theDriver : OCP.Storage.Storage_BaseDriver,theNumberOfObjects : int) -> None: ...
    pass
class StdObjMgt_SharedObject():
    def __init__(self) -> None: ...
    pass
class StdObjMgt_WriteData():
    """
    Auxiliary data used to write persistent objects to a file.
    """
    def WritePersistentObject(self,thePersistent : StdObjMgt_Persistent) -> None: ...
    def __init__(self,theDriver : OCP.Storage.Storage_BaseDriver) -> None: ...
    pass



import OCP.LDOM
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import LDOM_Node
import io
import LDOM_OSStream
import OCP.TCollection
import LDOM_XmlReader
__all__  = [
"LDOM_Node",
"LDOM_BasicNode",
"LDOM_BasicElement",
"LDOM_BasicAttribute",
"LDOM_CharacterData",
"LDOM_CharReference",
"LDOM_Text",
"LDOM_Comment",
"LDOM_Document",
"LDOM_DocumentType",
"LDOM_Element",
"LDOM_LDOMImplementation",
"LDOM_Attr",
"LDOM_NodeList",
"LDOM_OSStream",
"LDOM_SBuffer",
"LDOM_CDATASection",
"LDOM_XmlReader",
"LDOM_XmlWriter"
]
class LDOM_Node():
    class NodeType_e():
        pass
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,anOther : LDOM_Node) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_BasicNode():
    def GetSibling(self) -> LDOM_BasicNode: ...
    def getNodeType(self) -> Any: ...
    def isNull(self) -> bool: ...
    pass
class LDOM_BasicElement(LDOM_BasicNode):
    @staticmethod
    def Create_s(aName : str,aLength : int,aDoc : LDOM_MemManager) -> LDOM_BasicElement: ...
    def GetAttribute(self,aName : LDOMBasicString,aLastCh : LDOM_BasicNode) -> LDOM_BasicAttribute: ...
    def GetFirstChild(self) -> LDOM_BasicNode: ...
    def GetLastChild(self) -> LDOM_BasicNode: ...
    def GetSibling(self) -> LDOM_BasicNode: ...
    def GetTagName(self) -> str: ...
    def __init__(self) -> None: ...
    def getNodeType(self) -> Any: ...
    def isNull(self) -> bool: ...
    pass
class LDOM_BasicAttribute(LDOM_BasicNode):
    def GetName(self) -> str: ...
    def GetSibling(self) -> LDOM_BasicNode: ...
    def GetValue(self) -> LDOMBasicString: ...
    def __init__(self) -> None: ...
    def getNodeType(self) -> Any: ...
    def isNull(self) -> bool: ...
    pass
class LDOM_CharacterData(LDOM_Node):
    class NodeType_e():
        pass
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : LDOM_CharacterData) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getData(self) -> LDOMString: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getLength(self) -> int: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    def setData(self,aValue : LDOMString) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_CharReference():
    @staticmethod
    def Decode_s(theSrc : str,theLen : int) -> str: ...
    @staticmethod
    def Encode_s(theSrc : str,theLen : int,isAttribute : bool) -> str: ...
    def __init__(self) -> None: ...
    pass
class LDOM_Text(LDOM_CharacterData, LDOM_Node):
    class NodeType_e():
        pass
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,anOther : LDOM_Text) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getData(self) -> LDOMString: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getLength(self) -> int: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    def setData(self,aValue : LDOMString) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_Comment(LDOM_CharacterData, LDOM_Node):
    class NodeType_e():
        pass
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : LDOM_Comment) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getData(self) -> LDOMString: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getLength(self) -> int: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    def setData(self,aValue : LDOMString) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_Document():
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,aMemManager : LDOM_MemManager) -> None: ...
    def createCDATASection(self,theData : LDOMString) -> LDOM_CDATASection: ...
    def createComment(self,theData : LDOMString) -> LDOM_Comment: ...
    @staticmethod
    def createDocument_s(theQualifiedName : LDOMString) -> LDOM_Document: ...
    def createElement(self,theTagName : LDOMString) -> LDOM_Element: ...
    def createTextNode(self,theData : LDOMString) -> LDOM_Text: ...
    def getDocumentElement(self) -> LDOM_Element: ...
    def getElementsByTagName(self,theTagName : LDOMString) -> LDOM_NodeList: ...
    def isNull(self) -> bool: ...
    pass
class LDOM_DocumentType():
    def __init__(self) -> None: ...
    pass
class LDOM_Element(LDOM_Node):
    class NodeType_e():
        pass
    def GetAttributesList(self) -> LDOM_NodeList: ...
    def GetChildByTagName(self,aTagName : LDOMString) -> LDOM_Element: ...
    def GetSiblingByTagName(self) -> LDOM_Element: ...
    def ReplaceElement(self,anOther : LDOM_Element) -> None: ...
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,anOther : LDOM_Element) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getAttribute(self,aName : LDOMString) -> LDOMString: ...
    def getAttributeNode(self,aName : LDOMString) -> LDOM_Attr: ...
    def getElementsByTagName(self,aName : LDOMString) -> LDOM_NodeList: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def getTagName(self) -> LDOMString: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeAttribute(self,aName : LDOMString) -> None: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    def setAttribute(self,aName : LDOMString,aValue : LDOMString) -> None: ...
    def setAttributeNode(self,aNewAttr : LDOM_Attr) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_LDOMImplementation():
    def __init__(self) -> None: ...
    @staticmethod
    def createDocument_s(aNamespaceURI : LDOMString,aQualifiedName : LDOMString,aDocType : LDOM_DocumentType) -> LDOM_Document: ...
    pass
class LDOM_Attr(LDOM_Node):
    class NodeType_e():
        """
        Members:

          UNKNOWN

          ELEMENT_NODE

          ATTRIBUTE_NODE

          TEXT_NODE

          CDATA_SECTION_NODE

          COMMENT_NODE
        """
        def __eq__(self,other : object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __init__(self,value : int) -> None: ...
        def __int__(self) -> int: ...
        def __ne__(self,other : object) -> bool: ...
        def __repr__(self) -> str: ...
        def __setstate__(self,state : int) -> None: ...
        def __str__(self) -> str: ...
        @property
        def name(self) -> None:
            """
            :type: None
            """
        @property
        def value(self) -> int:
            """
            :type: int
            """
        ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
        CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
        COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
        ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
        TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
        UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
        __entries: dict # value = {'UNKNOWN': (<NodeType_e.UNKNOWN: 0>, None), 'ELEMENT_NODE': (<NodeType_e.ELEMENT_NODE: 1>, None), 'ATTRIBUTE_NODE': (<NodeType_e.ATTRIBUTE_NODE: 2>, None), 'TEXT_NODE': (<NodeType_e.TEXT_NODE: 3>, None), 'CDATA_SECTION_NODE': (<NodeType_e.CDATA_SECTION_NODE: 4>, None), 'COMMENT_NODE': (<NodeType_e.COMMENT_NODE: 8>, None)}
        __members__: dict # value = {'UNKNOWN': <NodeType_e.UNKNOWN: 0>, 'ELEMENT_NODE': <NodeType_e.ELEMENT_NODE: 1>, 'ATTRIBUTE_NODE': <NodeType_e.ATTRIBUTE_NODE: 2>, 'TEXT_NODE': <NodeType_e.TEXT_NODE: 3>, 'CDATA_SECTION_NODE': <NodeType_e.CDATA_SECTION_NODE: 4>, 'COMMENT_NODE': <NodeType_e.COMMENT_NODE: 8>}
        pass
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,anOther : LDOM_Attr) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getName(self) -> LDOMString: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def getValue(self) -> LDOMString: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    def setValue(self,aValue : LDOMString) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_NodeList():
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : LDOM_NodeList) -> None: ...
    def getLength(self) -> int: ...
    def item(self,arg0 : int) -> LDOM_Node: ...
    pass
class LDOM_OSStream():
    """
    Subclass if std::ostream allowing to increase performance of outputting data into a string avoiding reallocation of buffer. Class LDOM_OSStream implements output into a sequence of strings and getting the result as a string. It inherits Standard_OStream (std::ostream). Beside methods of std::ostream, it also has additional useful methods: str(), Length() and Clear().
    """
    class BOMType_e():
        """
        Members:

          BOM_UNDEFINED

          BOM_UTF8

          BOM_UTF16BE

          BOM_UTF16LE

          BOM_UTF32BE

          BOM_UTF32LE

          BOM_UTF7

          BOM_UTF1

          BOM_UTFEBCDIC

          BOM_SCSU

          BOM_BOCU1

          BOM_GB18030
        """
        def __eq__(self,other : object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __init__(self,value : int) -> None: ...
        def __int__(self) -> int: ...
        def __ne__(self,other : object) -> bool: ...
        def __repr__(self) -> str: ...
        def __setstate__(self,state : int) -> None: ...
        def __str__(self) -> str: ...
        @property
        def name(self) -> None:
            """
            :type: None
            """
        @property
        def value(self) -> int:
            """
            :type: int
            """
        BOM_BOCU1: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_BOCU1: 10>
        BOM_GB18030: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_GB18030: 11>
        BOM_SCSU: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_SCSU: 9>
        BOM_UNDEFINED: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UNDEFINED: 0>
        BOM_UTF1: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF1: 7>
        BOM_UTF16BE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF16BE: 2>
        BOM_UTF16LE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF16LE: 3>
        BOM_UTF32BE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF32BE: 4>
        BOM_UTF32LE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF32LE: 5>
        BOM_UTF7: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF7: 6>
        BOM_UTF8: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF8: 1>
        BOM_UTFEBCDIC: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTFEBCDIC: 8>
        __entries: dict # value = {'BOM_UNDEFINED': (<BOMType_e.BOM_UNDEFINED: 0>, None), 'BOM_UTF8': (<BOMType_e.BOM_UTF8: 1>, None), 'BOM_UTF16BE': (<BOMType_e.BOM_UTF16BE: 2>, None), 'BOM_UTF16LE': (<BOMType_e.BOM_UTF16LE: 3>, None), 'BOM_UTF32BE': (<BOMType_e.BOM_UTF32BE: 4>, None), 'BOM_UTF32LE': (<BOMType_e.BOM_UTF32LE: 5>, None), 'BOM_UTF7': (<BOMType_e.BOM_UTF7: 6>, None), 'BOM_UTF1': (<BOMType_e.BOM_UTF1: 7>, None), 'BOM_UTFEBCDIC': (<BOMType_e.BOM_UTFEBCDIC: 8>, None), 'BOM_SCSU': (<BOMType_e.BOM_SCSU: 9>, None), 'BOM_BOCU1': (<BOMType_e.BOM_BOCU1: 10>, None), 'BOM_GB18030': (<BOMType_e.BOM_GB18030: 11>, None)}
        __members__: dict # value = {'BOM_UNDEFINED': <BOMType_e.BOM_UNDEFINED: 0>, 'BOM_UTF8': <BOMType_e.BOM_UTF8: 1>, 'BOM_UTF16BE': <BOMType_e.BOM_UTF16BE: 2>, 'BOM_UTF16LE': <BOMType_e.BOM_UTF16LE: 3>, 'BOM_UTF32BE': <BOMType_e.BOM_UTF32BE: 4>, 'BOM_UTF32LE': <BOMType_e.BOM_UTF32LE: 5>, 'BOM_UTF7': <BOMType_e.BOM_UTF7: 6>, 'BOM_UTF1': <BOMType_e.BOM_UTF1: 7>, 'BOM_UTFEBCDIC': <BOMType_e.BOM_UTFEBCDIC: 8>, 'BOM_SCSU': <BOMType_e.BOM_SCSU: 9>, 'BOM_BOCU1': <BOMType_e.BOM_BOCU1: 10>, 'BOM_GB18030': <BOMType_e.BOM_GB18030: 11>}
        pass
    def Clear(self) -> None: ...
    def Length(self) -> int: ...
    def __init__(self,theMaxBuf : int) -> None: ...
    def str(self) -> str: ...
    BOM_BOCU1: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_BOCU1: 10>
    BOM_GB18030: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_GB18030: 11>
    BOM_SCSU: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_SCSU: 9>
    BOM_UNDEFINED: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UNDEFINED: 0>
    BOM_UTF1: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF1: 7>
    BOM_UTF16BE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF16BE: 2>
    BOM_UTF16LE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF16LE: 3>
    BOM_UTF32BE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF32BE: 4>
    BOM_UTF32LE: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF32LE: 5>
    BOM_UTF7: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF7: 6>
    BOM_UTF8: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTF8: 1>
    BOM_UTFEBCDIC: OCP.LDOM.BOMType_e # value = <BOMType_e.BOM_UTFEBCDIC: 8>
    pass
class LDOM_SBuffer():
    """
    Class LDOM_SBuffer inherits std::streambuf and redefines some virtual methods of it (overflow() and xsputn()). This class contains pointers on first and current element of sequence, also it has methods for the sequence management.
    """
    def Clear(self) -> None: 
        """
        Clears first element of sequence and removes all others
        """
    def Length(self) -> int: 
        """
        Returns full length of data contained
        """
    def __init__(self,theMaxBuf : int) -> None: ...
    def overflow(self,c : int=-1) -> int: ...
    def str(self) -> str: 
        """
        Concatenates strings of all sequence elements into one string. Space for output string is allocated with operator new. Caller of this function is responsible for memory release after the string usage.
        """
    def underflow(self) -> int: ...
    def xsputn(self,s : str,n : int) -> int: ...
    pass
class LDOM_CDATASection(LDOM_Text, LDOM_CharacterData, LDOM_Node):
    class NodeType_e():
        pass
    def SetValueClear(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theOther : LDOM_CDATASection) -> None: ...
    def appendChild(self,aChild : LDOM_Node) -> None: ...
    def getData(self) -> LDOMString: ...
    def getFirstChild(self) -> LDOM_Node: ...
    def getLastChild(self) -> LDOM_Node: ...
    def getLength(self) -> int: ...
    def getNextSibling(self) -> LDOM_Node: ...
    def getNodeName(self) -> LDOMString: ...
    def getNodeType(self) -> LDOM_Node.NodeType_e: ...
    def getNodeValue(self) -> LDOMString: ...
    def getOwnerDocument(self) -> LDOM_MemManager: ...
    def hasChildNodes(self) -> bool: ...
    def isNull(self) -> bool: ...
    def removeChild(self,aChild : LDOM_Node) -> None: ...
    def setData(self,aValue : LDOMString) -> None: ...
    ATTRIBUTE_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ATTRIBUTE_NODE: 2>
    CDATA_SECTION_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.CDATA_SECTION_NODE: 4>
    COMMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.COMMENT_NODE: 8>
    ELEMENT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.ELEMENT_NODE: 1>
    TEXT_NODE: OCP.LDOM.NodeType_e # value = <NodeType_e.TEXT_NODE: 3>
    UNKNOWN: OCP.LDOM.NodeType_e # value = <NodeType_e.UNKNOWN: 0>
    pass
class LDOM_XmlReader():
    class RecordType_e():
        """
        Members:

          XML_UNKNOWN

          XML_HEADER

          XML_DOCTYPE

          XML_COMMENT

          XML_START_ELEMENT

          XML_END_ELEMENT

          XML_FULL_ELEMENT

          XML_TEXT

          XML_CDATA

          XML_EOF
        """
        def __eq__(self,other : object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __init__(self,value : int) -> None: ...
        def __int__(self) -> int: ...
        def __ne__(self,other : object) -> bool: ...
        def __repr__(self) -> str: ...
        def __setstate__(self,state : int) -> None: ...
        def __str__(self) -> str: ...
        @property
        def name(self) -> None:
            """
            :type: None
            """
        @property
        def value(self) -> int:
            """
            :type: int
            """
        XML_CDATA: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_CDATA: 8>
        XML_COMMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_COMMENT: 3>
        XML_DOCTYPE: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_DOCTYPE: 2>
        XML_END_ELEMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_END_ELEMENT: 5>
        XML_EOF: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_EOF: 9>
        XML_FULL_ELEMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_FULL_ELEMENT: 6>
        XML_HEADER: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_HEADER: 1>
        XML_START_ELEMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_START_ELEMENT: 4>
        XML_TEXT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_TEXT: 7>
        XML_UNKNOWN: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_UNKNOWN: 0>
        __entries: dict # value = {'XML_UNKNOWN': (<RecordType_e.XML_UNKNOWN: 0>, None), 'XML_HEADER': (<RecordType_e.XML_HEADER: 1>, None), 'XML_DOCTYPE': (<RecordType_e.XML_DOCTYPE: 2>, None), 'XML_COMMENT': (<RecordType_e.XML_COMMENT: 3>, None), 'XML_START_ELEMENT': (<RecordType_e.XML_START_ELEMENT: 4>, None), 'XML_END_ELEMENT': (<RecordType_e.XML_END_ELEMENT: 5>, None), 'XML_FULL_ELEMENT': (<RecordType_e.XML_FULL_ELEMENT: 6>, None), 'XML_TEXT': (<RecordType_e.XML_TEXT: 7>, None), 'XML_CDATA': (<RecordType_e.XML_CDATA: 8>, None), 'XML_EOF': (<RecordType_e.XML_EOF: 9>, None)}
        __members__: dict # value = {'XML_UNKNOWN': <RecordType_e.XML_UNKNOWN: 0>, 'XML_HEADER': <RecordType_e.XML_HEADER: 1>, 'XML_DOCTYPE': <RecordType_e.XML_DOCTYPE: 2>, 'XML_COMMENT': <RecordType_e.XML_COMMENT: 3>, 'XML_START_ELEMENT': <RecordType_e.XML_START_ELEMENT: 4>, 'XML_END_ELEMENT': <RecordType_e.XML_END_ELEMENT: 5>, 'XML_FULL_ELEMENT': <RecordType_e.XML_FULL_ELEMENT: 6>, 'XML_TEXT': <RecordType_e.XML_TEXT: 7>, 'XML_CDATA': <RecordType_e.XML_CDATA: 8>, 'XML_EOF': <RecordType_e.XML_EOF: 9>}
        pass
    def CreateElement(self,theName : str,theLen : int) -> None: ...
    def GetBOM(self) -> LDOM_OSStream.BOMType_e: ...
    def GetElement(self) -> LDOM_BasicElement: ...
    def ReadRecord(self,theIStream : io.BytesIO,theData : LDOM_OSStream,theDocStart : bool) -> LDOM_XmlReader.RecordType_e: ...
    def __init__(self,aDocument : LDOM_MemManager,anErrorString : OCP.TCollection.TCollection_AsciiString,theTagPerStep : bool=False) -> None: ...
    @staticmethod
    def getInteger_s(theValue : LDOMBasicString,theStart : str,theEnd : str) -> bool: ...
    XML_CDATA: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_CDATA: 8>
    XML_COMMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_COMMENT: 3>
    XML_DOCTYPE: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_DOCTYPE: 2>
    XML_END_ELEMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_END_ELEMENT: 5>
    XML_EOF: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_EOF: 9>
    XML_FULL_ELEMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_FULL_ELEMENT: 6>
    XML_HEADER: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_HEADER: 1>
    XML_START_ELEMENT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_START_ELEMENT: 4>
    XML_TEXT: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_TEXT: 7>
    XML_UNKNOWN: OCP.LDOM.RecordType_e # value = <RecordType_e.XML_UNKNOWN: 0>
    pass
class LDOM_XmlWriter():
    def SetIndentation(self,theIndent : int) -> None: ...
    @overload
    def Write(self,theOStream : io.BytesIO,theDoc : LDOM_Document) -> None: ...
    @overload
    def Write(self,theOStream : io.BytesIO,theNode : LDOM_Node) -> None: ...
    def __init__(self,theEncoding : str=None) -> None: ...
    pass
